@@ -52,7 +52,16 @@ class CircleCiProps:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CircleCiProps.__init__)
+            def stub(
+                *,
+                jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
+                orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                setup: typing.Optional[builtins.bool] = None,
+                version: typing.Optional[jsii.Number] = None,
+                workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument jobs", value=jobs, expected_type=type_hints["jobs"])
             check_type(argname="argument orbs", value=orbs, expected_type=type_hints["orbs"])
             check_type(argname="argument setup", value=setup, expected_type=type_hints["setup"])
@@ -165,7 +174,17 @@ class Circleci(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Circleci.__init__)
+            def stub(
+                project: _Project_57d89203,
+                *,
+                jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
+                orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                setup: typing.Optional[builtins.bool] = None,
+                version: typing.Optional[jsii.Number] = None,
+                workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         options = CircleCiProps(
             jobs=jobs, orbs=orbs, setup=setup, version=version, workflows=workflows
@@ -185,7 +204,9 @@ class Circleci(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Circleci.add_orb)
+            def stub(name: builtins.str, orb: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument orb", value=orb, expected_type=type_hints["orb"])
         return typing.cast(None, jsii.invoke(self, "addOrb", [name, orb]))
@@ -214,7 +235,7 @@ class Circleci(
 
         return typing.cast(None, jsii.invoke(self, "addWorkflow", [workflow]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="file")
     def file(self) -> _YamlFile_909731b0:
         '''(experimental) The yaml file for the Circleci pipeline.
@@ -266,7 +287,19 @@ class Docker:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Docker.__init__)
+            def stub(
+                *,
+                image: builtins.str,
+                auth: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                aws_auth: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                command: typing.Optional[typing.Sequence[builtins.str]] = None,
+                entrypoint: typing.Optional[typing.Sequence[builtins.str]] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
+                name: typing.Optional[builtins.str] = None,
+                user: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
             check_type(argname="argument auth", value=auth, expected_type=type_hints["auth"])
             check_type(argname="argument aws_auth", value=aws_auth, expected_type=type_hints["aws_auth"])
@@ -416,7 +449,13 @@ class Filter:
         if isinstance(tags, dict):
             tags = FilterConfig(**tags)
         if __debug__:
-            type_hints = typing.get_type_hints(Filter.__init__)
+            def stub(
+                *,
+                branches: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
+                tags: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument branches", value=branches, expected_type=type_hints["branches"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -474,7 +513,13 @@ class FilterConfig:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FilterConfig.__init__)
+            def stub(
+                *,
+                ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
+                only: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument ignore", value=ignore, expected_type=type_hints["ignore"])
             check_type(argname="argument only", value=only, expected_type=type_hints["only"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -573,7 +618,22 @@ class Job:
         if isinstance(macos, dict):
             macos = Macos(**macos)
         if __debug__:
-            type_hints = typing.get_type_hints(Job.__init__)
+            def stub(
+                *,
+                identifier: builtins.str,
+                docker: typing.Optional[typing.Sequence[typing.Union[Docker, typing.Dict[str, typing.Any]]]] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
+                machine: typing.Optional[typing.Union["Machine", typing.Dict[str, typing.Any]]] = None,
+                macos: typing.Optional[typing.Union["Macos", typing.Dict[str, typing.Any]]] = None,
+                parallelism: typing.Optional[jsii.Number] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union["PipelineParameter", typing.Dict[str, typing.Any]]]] = None,
+                resource_class: typing.Optional[builtins.str] = None,
+                shell: typing.Optional[builtins.str] = None,
+                steps: typing.Optional[typing.Sequence[typing.Any]] = None,
+                working_directory: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
             check_type(argname="argument docker", value=docker, expected_type=type_hints["docker"])
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
@@ -781,7 +841,13 @@ class Machine:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Machine.__init__)
+            def stub(
+                *,
+                image: builtins.str,
+                docker_layer_caching: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
             check_type(argname="argument docker_layer_caching", value=docker_layer_caching, expected_type=type_hints["docker_layer_caching"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -842,7 +908,9 @@ class Macos:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Macos.__init__)
+            def stub(*, xcode: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument xcode", value=xcode, expected_type=type_hints["xcode"])
         self._values: typing.Dict[str, typing.Any] = {
             "xcode": xcode,
@@ -891,7 +959,13 @@ class Matrix:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Matrix.__init__)
+            def stub(
+                *,
+                alias: typing.Optional[builtins.str] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[typing.Sequence[builtins.str], typing.Sequence[jsii.Number]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -957,7 +1031,14 @@ class PipelineParameter:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PipelineParameter.__init__)
+            def stub(
+                *,
+                type: "PipelineParameterType",
+                default: typing.Optional[typing.Union[builtins.str, jsii.Number, builtins.bool]] = None,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
@@ -1122,7 +1203,19 @@ class Run:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Run.__init__)
+            def stub(
+                *,
+                command: builtins.str,
+                background: typing.Optional[builtins.str] = None,
+                environment: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                no_output_timeout: typing.Optional[builtins.str] = None,
+                shell: typing.Optional[builtins.str] = None,
+                when: typing.Optional[builtins.str] = None,
+                working_directory: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument command", value=command, expected_type=type_hints["command"])
             check_type(argname="argument background", value=background, expected_type=type_hints["background"])
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
@@ -1259,7 +1352,13 @@ class Schedule:
         if isinstance(filters, dict):
             filters = Filter(**filters)
         if __debug__:
-            type_hints = typing.get_type_hints(Schedule.__init__)
+            def stub(
+                *,
+                filters: typing.Union[Filter, typing.Dict[str, typing.Any]],
+                cron: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
             check_type(argname="argument cron", value=cron, expected_type=type_hints["cron"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -1319,7 +1418,12 @@ class StepRun:
         if isinstance(run, dict):
             run = Run(**run)
         if __debug__:
-            type_hints = typing.get_type_hints(StepRun.__init__)
+            def stub(
+                *,
+                run: typing.Optional[typing.Union[Run, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument run", value=run, expected_type=type_hints["run"])
         self._values: typing.Dict[str, typing.Any] = {}
         if run is not None:
@@ -1368,7 +1472,12 @@ class Triggers:
         if isinstance(schedule, dict):
             schedule = Schedule(**schedule)
         if __debug__:
-            type_hints = typing.get_type_hints(Triggers.__init__)
+            def stub(
+                *,
+                schedule: typing.Optional[typing.Union[Schedule, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
         self._values: typing.Dict[str, typing.Any] = {}
         if schedule is not None:
@@ -1428,7 +1537,15 @@ class Workflow:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Workflow.__init__)
+            def stub(
+                *,
+                identifier: builtins.str,
+                jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[str, typing.Any]]]] = None,
+                triggers: typing.Optional[typing.Sequence[typing.Union[Triggers, typing.Dict[str, typing.Any]]]] = None,
+                when: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
             check_type(argname="argument jobs", value=jobs, expected_type=type_hints["jobs"])
             check_type(argname="argument triggers", value=triggers, expected_type=type_hints["triggers"])
@@ -1541,7 +1658,19 @@ class WorkflowJob:
         if isinstance(matrix, dict):
             matrix = Matrix(**matrix)
         if __debug__:
-            type_hints = typing.get_type_hints(WorkflowJob.__init__)
+            def stub(
+                *,
+                identifier: builtins.str,
+                context: typing.Optional[typing.Sequence[builtins.str]] = None,
+                filters: typing.Optional[typing.Union[Filter, typing.Dict[str, typing.Any]]] = None,
+                matrix: typing.Optional[typing.Union[Matrix, typing.Dict[str, typing.Any]]] = None,
+                name: typing.Optional[builtins.str] = None,
+                orb_parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
+                requires: typing.Optional[typing.Sequence[builtins.str]] = None,
+                type: typing.Optional[JobType] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
             check_type(argname="argument context", value=context, expected_type=type_hints["context"])
             check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
