@@ -22,6 +22,27 @@ from .. import (
 )
 
 
+@jsii.enum(jsii_type="projen.vscode.Console")
+class Console(enum.Enum):
+    '''(experimental) Controls where to launch the debug target Source: https://code.visualstudio.com/docs/editor/debugging#_launchjson-attributes.
+
+    :stability: experimental
+    '''
+
+    INTERNAL_CONSOLE = "INTERNAL_CONSOLE"
+    '''
+    :stability: experimental
+    '''
+    INTEGRATED_TERMINAL = "INTEGRATED_TERMINAL"
+    '''
+    :stability: experimental
+    '''
+    EXTERNAL_TERMINAL = "EXTERNAL_TERMINAL"
+    '''
+    :stability: experimental
+    '''
+
+
 @jsii.implements(_IDevEnvironment_9a084622)
 class DevContainer(
     _Component_2b0ad27f,
@@ -55,7 +76,16 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DevContainer.__init__)
+            def stub(
+                project: _Project_57d89203,
+                *,
+                docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
+                ports: typing.Optional[typing.Sequence[builtins.str]] = None,
+                tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
+                vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         options = DevContainerOptions(
             docker_image=docker_image,
@@ -75,7 +105,9 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DevContainer.add_docker_image)
+            def stub(image: _DevEnvironmentDockerImage_4a8d8ffd) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast(None, jsii.invoke(self, "addDockerImage", [image]))
 
@@ -88,8 +120,10 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DevContainer.add_ports)
-            check_type(argname="argument ports", value=ports, expected_type=typing.Tuple[type_hints["ports"], ...])
+            def stub(*ports: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument ports", value=ports, expected_type=typing.Tuple[type_hints["ports"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addPorts", [*ports]))
 
     @jsii.member(jsii_name="addTasks")
@@ -103,8 +137,10 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DevContainer.add_tasks)
-            check_type(argname="argument tasks", value=tasks, expected_type=typing.Tuple[type_hints["tasks"], ...])
+            def stub(*tasks: _Task_9fa875b6) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument tasks", value=tasks, expected_type=typing.Tuple[type_hints["tasks"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addTasks", [*tasks]))
 
     @jsii.member(jsii_name="addVscodeExtensions")
@@ -116,11 +152,13 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DevContainer.add_vscode_extensions)
-            check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...])
+            def stub(*extensions: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addVscodeExtensions", [*extensions]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="config")
     def config(self) -> typing.Any:
         '''(experimental) Direct access to the devcontainer configuration (escape hatch).
@@ -162,7 +200,15 @@ class DevContainerOptions(_DevEnvironmentOptions_b10d89d1):
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DevContainerOptions.__init__)
+            def stub(
+                *,
+                docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
+                ports: typing.Optional[typing.Sequence[builtins.str]] = None,
+                tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
+                vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument docker_image", value=docker_image, expected_type=type_hints["docker_image"])
             check_type(argname="argument ports", value=ports, expected_type=type_hints["ports"])
             check_type(argname="argument tasks", value=tasks, expected_type=type_hints["tasks"])
@@ -268,7 +314,14 @@ class Presentation:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Presentation.__init__)
+            def stub(
+                *,
+                group: builtins.str,
+                hidden: builtins.bool,
+                order: jsii.Number,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument group", value=group, expected_type=type_hints["group"])
             check_type(argname="argument hidden", value=hidden, expected_type=type_hints["hidden"])
             check_type(argname="argument order", value=order, expected_type=type_hints["order"])
@@ -339,7 +392,14 @@ class ServerReadyAction:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ServerReadyAction.__init__)
+            def stub(
+                *,
+                action: builtins.str,
+                pattern: typing.Optional[builtins.str] = None,
+                uri_format: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument action", value=action, expected_type=type_hints["action"])
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
             check_type(argname="argument uri_format", value=uri_format, expected_type=type_hints["uri_format"])
@@ -404,11 +464,21 @@ class VsCode(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VsCode.__init__)
+            def stub(project: _Project_57d89203) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         jsii.create(self.__class__, self, [project])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
+    @jsii.member(jsii_name="extensions")
+    def extensions(self) -> "VsCodeRecommendedExtensions":
+        '''
+        :stability: experimental
+        '''
+        return typing.cast("VsCodeRecommendedExtensions", jsii.get(self, "extensions"))
+
+    @builtins.property
     @jsii.member(jsii_name="launchConfiguration")
     def launch_configuration(self) -> "VsCodeLaunchConfig":
         '''
@@ -416,6 +486,14 @@ class VsCode(
         '''
         return typing.cast("VsCodeLaunchConfig", jsii.get(self, "launchConfiguration"))
 
+    @builtins.property
+    @jsii.member(jsii_name="settings")
+    def settings(self) -> "VsCodeSettings":
+        '''
+        :stability: experimental
+        '''
+        return typing.cast("VsCodeSettings", jsii.get(self, "settings"))
+
 
 class VsCodeLaunchConfig(
     _Component_2b0ad27f,
@@ -434,7 +512,9 @@ class VsCodeLaunchConfig(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VsCodeLaunchConfig.__init__)
+            def stub(vscode: VsCode) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
         jsii.create(self.__class__, self, [vscode])
 
@@ -446,9 +526,15 @@ class VsCodeLaunchConfig(
         request: builtins.str,
         type: builtins.str,
         args: typing.Optional[typing.Sequence[builtins.str]] = None,
+        console: typing.Optional[Console] = None,
+        cwd: typing.Optional[builtins.str] = None,
         debug_server: typing.Optional[jsii.Number] = None,
+        disable_optimistic_b_ps: typing.Optional[builtins.bool] = None,
+        env: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]] = None,
+        env_file: typing.Optional[builtins.str] = None,
         internal_console_options: typing.Optional[InternalConsoleOptions] = None,
         out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+        port: typing.Optional[jsii.Number] = None,
         post_debug_task: typing.Optional[builtins.str] = None,
         pre_launch_task: typing.Optional[builtins.str] = None,
         presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
@@ -456,6 +542,7 @@ class VsCodeLaunchConfig(
         runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
         server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
         skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+        stop_on_entry: typing.Optional[builtins.bool] = None,
         url: typing.Optional[builtins.str] = None,
         web_root: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -465,9 +552,15 @@ class VsCodeLaunchConfig(
         :param request: 
         :param type: 
         :param args: 
+        :param console: 
+        :param cwd: 
         :param debug_server: 
+        :param disable_optimistic_b_ps: 
+        :param env: (experimental) Set value to ``false`` to unset an existing environment variable.
+        :param env_file: 
         :param internal_console_options: 
         :param out_files: 
+        :param port: 
         :param post_debug_task: 
         :param pre_launch_task: 
         :param presentation: 
@@ -475,6 +568,7 @@ class VsCodeLaunchConfig(
         :param runtime_args: 
         :param server_ready_action: 
         :param skip_files: 
+        :param stop_on_entry: 
         :param url: 
         :param web_root: 
 
@@ -485,9 +579,15 @@ class VsCodeLaunchConfig(
             request=request,
             type=type,
             args=args,
+            console=console,
+            cwd=cwd,
             debug_server=debug_server,
+            disable_optimistic_b_ps=disable_optimistic_b_ps,
+            env=env,
+            env_file=env_file,
             internal_console_options=internal_console_options,
             out_files=out_files,
+            port=port,
             post_debug_task=post_debug_task,
             pre_launch_task=pre_launch_task,
             presentation=presentation,
@@ -495,6 +595,7 @@ class VsCodeLaunchConfig(
             runtime_args=runtime_args,
             server_ready_action=server_ready_action,
             skip_files=skip_files,
+            stop_on_entry=stop_on_entry,
             url=url,
             web_root=web_root,
         )
@@ -510,9 +611,15 @@ class VsCodeLaunchConfig(
         "request": "request",
         "type": "type",
         "args": "args",
+        "console": "console",
+        "cwd": "cwd",
         "debug_server": "debugServer",
+        "disable_optimistic_b_ps": "disableOptimisticBPs",
+        "env": "env",
+        "env_file": "envFile",
         "internal_console_options": "internalConsoleOptions",
         "out_files": "outFiles",
+        "port": "port",
         "post_debug_task": "postDebugTask",
         "pre_launch_task": "preLaunchTask",
         "presentation": "presentation",
@@ -520,6 +627,7 @@ class VsCodeLaunchConfig(
         "runtime_args": "runtimeArgs",
         "server_ready_action": "serverReadyAction",
         "skip_files": "skipFiles",
+        "stop_on_entry": "stopOnEntry",
         "url": "url",
         "web_root": "webRoot",
     },
@@ -532,9 +640,15 @@ class VsCodeLaunchConfigurationEntry:
         request: builtins.str,
         type: builtins.str,
         args: typing.Optional[typing.Sequence[builtins.str]] = None,
+        console: typing.Optional[Console] = None,
+        cwd: typing.Optional[builtins.str] = None,
         debug_server: typing.Optional[jsii.Number] = None,
+        disable_optimistic_b_ps: typing.Optional[builtins.bool] = None,
+        env: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]] = None,
+        env_file: typing.Optional[builtins.str] = None,
         internal_console_options: typing.Optional[InternalConsoleOptions] = None,
         out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+        port: typing.Optional[jsii.Number] = None,
         post_debug_task: typing.Optional[builtins.str] = None,
         pre_launch_task: typing.Optional[builtins.str] = None,
         presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
@@ -542,6 +656,7 @@ class VsCodeLaunchConfigurationEntry:
         runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
         server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
         skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+        stop_on_entry: typing.Optional[builtins.bool] = None,
         url: typing.Optional[builtins.str] = None,
         web_root: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -551,9 +666,15 @@ class VsCodeLaunchConfigurationEntry:
         :param request: 
         :param type: 
         :param args: 
+        :param console: 
+        :param cwd: 
         :param debug_server: 
+        :param disable_optimistic_b_ps: 
+        :param env: (experimental) Set value to ``false`` to unset an existing environment variable.
+        :param env_file: 
         :param internal_console_options: 
         :param out_files: 
+        :param port: 
         :param post_debug_task: 
         :param pre_launch_task: 
         :param presentation: 
@@ -561,6 +682,7 @@ class VsCodeLaunchConfigurationEntry:
         :param runtime_args: 
         :param server_ready_action: 
         :param skip_files: 
+        :param stop_on_entry: 
         :param url: 
         :param web_root: 
 
@@ -571,14 +693,47 @@ class VsCodeLaunchConfigurationEntry:
         if isinstance(server_ready_action, dict):
             server_ready_action = ServerReadyAction(**server_ready_action)
         if __debug__:
-            type_hints = typing.get_type_hints(VsCodeLaunchConfigurationEntry.__init__)
+            def stub(
+                *,
+                name: builtins.str,
+                request: builtins.str,
+                type: builtins.str,
+                args: typing.Optional[typing.Sequence[builtins.str]] = None,
+                console: typing.Optional[Console] = None,
+                cwd: typing.Optional[builtins.str] = None,
+                debug_server: typing.Optional[jsii.Number] = None,
+                disable_optimistic_b_ps: typing.Optional[builtins.bool] = None,
+                env: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]] = None,
+                env_file: typing.Optional[builtins.str] = None,
+                internal_console_options: typing.Optional[InternalConsoleOptions] = None,
+                out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+                port: typing.Optional[jsii.Number] = None,
+                post_debug_task: typing.Optional[builtins.str] = None,
+                pre_launch_task: typing.Optional[builtins.str] = None,
+                presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
+                program: typing.Optional[builtins.str] = None,
+                runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
+                server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
+                skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+                stop_on_entry: typing.Optional[builtins.bool] = None,
+                url: typing.Optional[builtins.str] = None,
+                web_root: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument request", value=request, expected_type=type_hints["request"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument args", value=args, expected_type=type_hints["args"])
+            check_type(argname="argument console", value=console, expected_type=type_hints["console"])
+            check_type(argname="argument cwd", value=cwd, expected_type=type_hints["cwd"])
             check_type(argname="argument debug_server", value=debug_server, expected_type=type_hints["debug_server"])
+            check_type(argname="argument disable_optimistic_b_ps", value=disable_optimistic_b_ps, expected_type=type_hints["disable_optimistic_b_ps"])
+            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
+            check_type(argname="argument env_file", value=env_file, expected_type=type_hints["env_file"])
             check_type(argname="argument internal_console_options", value=internal_console_options, expected_type=type_hints["internal_console_options"])
             check_type(argname="argument out_files", value=out_files, expected_type=type_hints["out_files"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
             check_type(argname="argument post_debug_task", value=post_debug_task, expected_type=type_hints["post_debug_task"])
             check_type(argname="argument pre_launch_task", value=pre_launch_task, expected_type=type_hints["pre_launch_task"])
             check_type(argname="argument presentation", value=presentation, expected_type=type_hints["presentation"])
@@ -586,6 +741,7 @@ class VsCodeLaunchConfigurationEntry:
             check_type(argname="argument runtime_args", value=runtime_args, expected_type=type_hints["runtime_args"])
             check_type(argname="argument server_ready_action", value=server_ready_action, expected_type=type_hints["server_ready_action"])
             check_type(argname="argument skip_files", value=skip_files, expected_type=type_hints["skip_files"])
+            check_type(argname="argument stop_on_entry", value=stop_on_entry, expected_type=type_hints["stop_on_entry"])
             check_type(argname="argument url", value=url, expected_type=type_hints["url"])
             check_type(argname="argument web_root", value=web_root, expected_type=type_hints["web_root"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -595,12 +751,24 @@ class VsCodeLaunchConfigurationEntry:
         }
         if args is not None:
             self._values["args"] = args
+        if console is not None:
+            self._values["console"] = console
+        if cwd is not None:
+            self._values["cwd"] = cwd
         if debug_server is not None:
             self._values["debug_server"] = debug_server
+        if disable_optimistic_b_ps is not None:
+            self._values["disable_optimistic_b_ps"] = disable_optimistic_b_ps
+        if env is not None:
+            self._values["env"] = env
+        if env_file is not None:
+            self._values["env_file"] = env_file
         if internal_console_options is not None:
             self._values["internal_console_options"] = internal_console_options
         if out_files is not None:
             self._values["out_files"] = out_files
+        if port is not None:
+            self._values["port"] = port
         if post_debug_task is not None:
             self._values["post_debug_task"] = post_debug_task
         if pre_launch_task is not None:
@@ -615,6 +783,8 @@ class VsCodeLaunchConfigurationEntry:
             self._values["server_ready_action"] = server_ready_action
         if skip_files is not None:
             self._values["skip_files"] = skip_files
+        if stop_on_entry is not None:
+            self._values["stop_on_entry"] = stop_on_entry
         if url is not None:
             self._values["url"] = url
         if web_root is not None:
@@ -655,6 +825,22 @@ class VsCodeLaunchConfigurationEntry:
         result = self._values.get("args")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def console(self) -> typing.Optional[Console]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("console")
+        return typing.cast(typing.Optional[Console], result)
+
+    @builtins.property
+    def cwd(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("cwd")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def debug_server(self) -> typing.Optional[jsii.Number]:
         '''
@@ -663,6 +849,33 @@ class VsCodeLaunchConfigurationEntry:
         result = self._values.get("debug_server")
         return typing.cast(typing.Optional[jsii.Number], result)
 
+    @builtins.property
+    def disable_optimistic_b_ps(self) -> typing.Optional[builtins.bool]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("disable_optimistic_b_ps")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def env(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]]:
+        '''(experimental) Set value to ``false`` to unset an existing environment variable.
+
+        :stability: experimental
+        '''
+        result = self._values.get("env")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]], result)
+
+    @builtins.property
+    def env_file(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("env_file")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def internal_console_options(self) -> typing.Optional[InternalConsoleOptions]:
         '''
@@ -679,6 +892,14 @@ class VsCodeLaunchConfigurationEntry:
         result = self._values.get("out_files")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def port(self) -> typing.Optional[jsii.Number]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("port")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     @builtins.property
     def post_debug_task(self) -> typing.Optional[builtins.str]:
         '''
@@ -735,6 +956,14 @@ class VsCodeLaunchConfigurationEntry:
         result = self._values.get("skip_files")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def stop_on_entry(self) -> typing.Optional[builtins.bool]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("stop_on_entry")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def url(self) -> typing.Optional[builtins.str]:
         '''
@@ -763,7 +992,140 @@ class VsCodeLaunchConfigurationEntry:
         )
 
 
+class VsCodeRecommendedExtensions(
+    _Component_2b0ad27f,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="projen.vscode.VsCodeRecommendedExtensions",
+):
+    '''(experimental) VS Code Workspace recommended extensions Source: https://code.visualstudio.com/docs/editor/extension-marketplace#_workspace-recommended-extensions.
+
+    :stability: experimental
+    '''
+
+    def __init__(self, vscode: VsCode) -> None:
+        '''
+        :param vscode: -
+
+        :stability: experimental
+        '''
+        if __debug__:
+            def stub(vscode: VsCode) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
+        jsii.create(self.__class__, self, [vscode])
+
+    @jsii.member(jsii_name="addRecommendations")
+    def add_recommendations(self, *extensions: builtins.str) -> None:
+        '''(experimental) Adds a list of VS Code extensions as recommendations for this workspace.
+
+        :param extensions: The extension IDs.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            def stub(*extensions: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
+        return typing.cast(None, jsii.invoke(self, "addRecommendations", [*extensions]))
+
+    @jsii.member(jsii_name="addUnwantedRecommendations")
+    def add_unwanted_recommendations(self, *extensions: builtins.str) -> None:
+        '''(experimental) Marks a list of VS Code extensions as unwanted recommendations for this workspace.
+
+        VS Code should not be recommend these extensions for users of this workspace.
+
+        :param extensions: The extension IDs.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            def stub(*extensions: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
+        return typing.cast(None, jsii.invoke(self, "addUnwantedRecommendations", [*extensions]))
+
+
+class VsCodeSettings(
+    _Component_2b0ad27f,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="projen.vscode.VsCodeSettings",
+):
+    '''(experimental) VS Code Workspace settings Source: https://code.visualstudio.com/docs/getstarted/settings#_workspace-settings.
+
+    :stability: experimental
+    '''
+
+    def __init__(self, vscode: VsCode) -> None:
+        '''
+        :param vscode: -
+
+        :stability: experimental
+        '''
+        if __debug__:
+            def stub(vscode: VsCode) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
+        jsii.create(self.__class__, self, [vscode])
+
+    @jsii.member(jsii_name="addSetting")
+    def add_setting(
+        self,
+        setting: builtins.str,
+        value: typing.Any,
+        language: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''(experimental) Adds a workspace setting.
+
+        :param setting: The setting ID.
+        :param value: The value of the setting.
+        :param language: Scope the setting to a specific language.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            def stub(
+                setting: builtins.str,
+                value: typing.Any,
+                language: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument setting", value=setting, expected_type=type_hints["setting"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+            check_type(argname="argument language", value=language, expected_type=type_hints["language"])
+        return typing.cast(None, jsii.invoke(self, "addSetting", [setting, value, language]))
+
+    @jsii.member(jsii_name="addSettings")
+    def add_settings(
+        self,
+        settings: typing.Mapping[builtins.str, typing.Any],
+        languages: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
+    ) -> None:
+        '''(experimental) Adds a workspace setting.
+
+        :param settings: Array structure: [setting: string, value: any, languages?: string[]].
+        :param languages: -
+
+        :stability: experimental
+        '''
+        if __debug__:
+            def stub(
+                settings: typing.Mapping[builtins.str, typing.Any],
+                languages: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
+            check_type(argname="argument languages", value=languages, expected_type=type_hints["languages"])
+        return typing.cast(None, jsii.invoke(self, "addSettings", [settings, languages]))
+
+
 __all__ = [
+    "Console",
     "DevContainer",
     "DevContainerOptions",
     "InternalConsoleOptions",
@@ -772,6 +1134,8 @@ __all__ = [
     "VsCode",
     "VsCodeLaunchConfig",
     "VsCodeLaunchConfigurationEntry",
+    "VsCodeRecommendedExtensions",
+    "VsCodeSettings",
 ]
 
 publication.publish()
